// src/useStateRef.ts
import { useEffect, useRef, useState } from "react";
function useStateRef(initialValue) {
  const [state, setState] = useState(initialValue);
  const ref = useRef(initialValue);
  useEffect(() => {
    ref.current = state;
  }, [state]);
  return [state, setState, ref];
}
var useStateRef_default = useStateRef;

// src/useReducerRef.ts
import { useCallback, useRef as useRef2, useState as useState2 } from "react";
function useReducerRef_default(reducer, initialValue) {
  const [state, setState] = useState2(initialValue);
  const ref = useRef2(initialValue);
  const reducerRef = useRef2(reducer);
  const dispatch = useCallback((action) => {
    ref.current = reducerRef.current(ref.current, action);
    setState(ref.current);
  }, []);
  return [state, dispatch, ref];
}

// src/useDebounce.ts
import { useCallback as useCallback2, useRef as useRef3 } from "react";
function useDebounce_default(fn, delay = 2e3, normalFn) {
  const timer = useRef3();
  return useCallback2(
    function inner(...args) {
      normalFn?.(args);
      timer.current && clearTimeout(timer.current);
      timer.current = setTimeout(() => fn(args), delay);
    },
    [delay, fn, normalFn]
  );
}

// src/useStateDebounce.ts
import { useEffect as useEffect2, useState as useState3 } from "react";
function useStateDebounce(initialValue, delay = 2e3) {
  const [state, setState] = useState3(initialValue);
  const [delayState, setDelayState] = useState3(initialValue);
  useEffect2(() => {
    const timer = setTimeout(() => {
      setDelayState(state);
    }, delay);
    return () => clearTimeout(timer);
  }, [delay, state]);
  return [state, setState, delayState, setDelayState];
}
var useStateDebounce_default = useStateDebounce;

// src/useDebounceValue.ts
import { useEffect as useEffect3, useRef as useRef4, useState as useState4 } from "react";
function useDebounceValue(value, delay = 0) {
  const [cur, setCur] = useState4(value);
  const timerRef = useRef4(null);
  useEffect3(() => {
    timerRef.current && clearTimeout(timerRef.current);
    timerRef.current = setTimeout(() => {
      setCur(value);
    }, delay);
  }, [value]);
  return cur;
}
var useDebounceValue_default = useDebounceValue;
export {
  useDebounce_default as useDebounce,
  useDebounceValue_default as useDebounceValue,
  useReducerRef_default as useReducerRef,
  useStateDebounce_default as useStateDebounce,
  useStateRef_default as useStateRef
};
